@@ -2,7 +2,7 @@ fn main() {
     tonic_build::configure()
     .build_client(true)
     .build_server(true)
-    .format(true)
+    .format(false)
     .compile(&[
         "opentelemetry-proto/opentelemetry/proto/collector/logs/v1/logs_service.proto",
         "opentelemetry-proto/opentelemetry/proto/collector/metrics/v1/metrics_service.proto",
